import { fetchProvincesList } from '@/api/base/index';

const GET_LIST = 'GET_LIST';
const FETCH_STATE = 'FETCH_STATE';
const FETCH_DONE = 'FETCH_DONE';

const state = () => ({
  list: [],
  fetching: [],
});

const getters = {
  provincesList: state => state.list,
};

const actions = {
  fetchProvincesList({ state, commit }, info) {
    const id = info ? info.id : 0;
    if (state.fetching.find(item => item.id === id)) return;
    commit(FETCH_STATE, id);
    const entity = info
      ? {
          params: { id: info.id },
        }
      : {};
    return fetchProvincesList(entity)
      .then(res => {
        const list = res.data;
        if (list && list.length) {
          commit(GET_LIST, { list, info });
        }
        commit(FETCH_DONE, id);
      })
      .catch(err => {
        console.error(err);
        commit(FETCH_DONE, id);
      });
  },
  fetchPCAList({ state, commit }, fetchArr) {
    const initState = state.list.length
      ? {
          list: state.list,
          fetchHandle: Promise.resolve(),
        }
      : {
          list: state.list,
          fetchHandle: fetchProvincesList().then(res => {
            const list = res.data;
            if (list && list.length) {
              commit(GET_LIST, { list, info: null });
            }
          }),
        };
    return fetchArr.reduce(({ list, fetchHandle }, val, idx, oArr) => {
      if (idx === 2) {
        return;
      }
      if (list && list.length) {
        let area = list.find(item => item.id === val);
        if (area && area.children && area.children.length) {
          return {
            list: area.children,
            fetchHandle,
          };
        }
      }
      return {
        list: [],
        fetchHandle: fetchHandle
          .then(() =>
            fetchProvincesList({
              params: { id: val },
            })
          )
          .then(res => {
            const list = res.data;
            if (list && list.length) {
              commit(GET_LIST, {
                list,
                info: {
                  id: val,
                  level: oArr.slice(0, idx + 1),
                },
              });
            }
          }),
      };
    }, initState);
  },
};

const mutations = {
  [GET_LIST](state, { list, info }) {
    if (info) {
      info.level.reduce((curList, val, idx) => {
        let area = curList.find(item => item.id === val);
        if (idx === info.level.length - 1) {
          area.children =
            info.level.length === 2
              ? list
              : list.map(item => ({ ...item, children: [] }));
          return;
        } else {
          return area.children;
        }
      }, state.list);
    } else {
      state.list = list.map(item => ({ ...item, children: [] }));
    }
  },
  [FETCH_STATE](state, id) {
    state.fetching.push(id);
  },
  [FETCH_DONE](state, id) {
    state.fetching = state.fetching.filter(item => item.id !== id);
  },
};

export default {
  namespaced: true,
  state,
  getters,
  actions,
  mutations,
};
