import {
  fetchBeanInfoByUser,
  increaseBeanByUser,
  decreaseBeanByUser,
  fetchBeanInfoByArea,
  increaseBeanByArea,
  decreaseBeanByArea,
} from '../../../api/account/beanHandsel';
import { fetchUserInfo } from '../../../api/customer/customerInfo';

import storeModule from '@/lib/storeModule';
const initFiltersStore = storeModule.filter;

const initFilters = () => ({
  filterType: '',
  customerId: null,
  customerPhone: '',
});
const filtersStore = initFiltersStore(initFilters, {
  filterType: state => state.filters.filterType,
});

const GET_SELECTED_INFO = 'GET_SELECTED_INFO';
const GET_AREA_INFO = 'GET_AREA_INFO';
const UPDATE_FILTER_TYPE = 'UPDATE_FILTER_TYPE';
const CLEAR_STORE = 'CLEAR_STORE';

const initSelected = () => ({
  areaId: null,
  areaName: '',
  customerId: null,
  customerPhone: '',
  beanGroup: [],
});
const initAreaInfo = () => ({
  areaId: null,
  areaName: '',
  customerType: '',
  beanGroup: [],
  number: null,
});
const state = () => ({
  selected: initSelected(),
  areaInfo: initAreaInfo(),
});

const getters = {
  selected: state => state.selected,
  areaInfo: state => state.areaInfo,
};
const actions = {
  fetchBeanInfoByUser({ commit }, entity) {
    return fetchBeanInfoByUser({
      params: entity,
    })
      .then(res => {
        const { beanGroup } = res.data;
        // if(beanGroup.length==0){
        //   entity.customerPhone = null;
        //   entity.customerId = null;
        // }
        // console.log(beanGroup,entity.customerPhone);
        commit(GET_SELECTED_INFO, {
          ...entity,
          beanGroup,
        });
      })
      .catch(err => {
        console.error(err);
        commit(GET_SELECTED_INFO, initSelected());
      });
  },
  increaseBeanByUser({ state, dispatch }, entity) {
    entity = {
      ...entity,
      customerId: state.selected.customerId,
      customerPhone: state.selected.customerPhone,
    };
    console.log(entity);
    return increaseBeanByUser({
      data: entity,
    }).then(res => {
      dispatch('fetchBeanInfoByUser', {
        customerId: state.selected.customerId,
        customerPhone: state.selected.customerPhone,
      });
      return res;
    });
  },
  decreaseBeanByUser({ state, dispatch }, entity) {
    entity = {
      ...entity,
      customerId: state.selected.customerId,
      customerPhone: state.selected.customerPhone,
    };
    return decreaseBeanByUser({
      data: entity,
    }).then(res => {
      dispatch('fetchBeanInfoByUser', {
        customerId: state.selected.customerId,
        customerPhone: state.selected.customerPhone,
      });
      return res;
    });
  },
  fetchUserInfo({ commit, state, dispatch }, entity) {
    return fetchUserInfo({
      params: { ...entity },
    });
  },
  fetchBeanInfoByArea({ commit }, entity) {
    return fetchBeanInfoByArea({
      params: entity,
    })
      .then(res => {
        const { beanGroup, number } = res.data;
        commit(GET_AREA_INFO, {
          areaId: entity.areaId,
          areaName: entity.areaName,
          customerType: entity.customerType,
          beanGroup,
          number,
        });
      })
      .catch(err => {
        console.error(err);
        commit(GET_AREA_INFO, initAreaInfo());
      });
  },
  increaseBeanByArea({ state, dispatch }, entity) {
    entity = {
      ...entity,
      areaId: state.areaInfo.areaId,
      areaName: state.areaInfo.areaName,
      customerType: state.areaInfo.customerType,
    };
    return increaseBeanByArea({
      data: entity,
    }).then(res => {
      dispatch('fetchBeanInfoByArea', {
        areaId: state.areaInfo.areaId,
        areaName: state.areaInfo.areaName,
        customerType: state.areaInfo.customerType,
      });
      return res;
    });
  },
  decreaseBeanByArea({ state, dispatch }, entity) {
    entity = {
      ...entity,
      areaId: state.areaInfo.areaId,
      areaName: state.areaInfo.areaName,
      customerType: state.areaInfo.customerType,
    };
    return decreaseBeanByArea({
      data: entity,
    }).then(res => {
      dispatch('fetchBeanInfoByArea', {
        areaId: state.areaInfo.areaId,
        areaName: state.areaInfo.areaName,
        customerType: state.areaInfo.customerType,
      });
      return res;
    });
  },
  clearStore({ commit, dispatch }) {
    dispatch('updateFilters', initFilters());
    commit(CLEAR_STORE);
  },
};
const mutations = {
  [UPDATE_FILTER_TYPE](state, data) {
    state.filterType = data;
  },
  [GET_SELECTED_INFO](state, data) {
    console.log(data);
    state.selected = {
      ...state.selected,
      ...data,
    };
  },
  [GET_AREA_INFO](state, data) {
    state.areaInfo = {
      ...state.areaInfo,
      ...data,
    };
  },
  [CLEAR_STORE](state) {
    state.selected = initSelected();
    state.areaInfo = initAreaInfo();
  },
};

export default {
  namespaced: true,
  modules: {
    filtersStore,
  },
  state,
  getters,
  actions,
  mutations,
};
