import storeModule from '@/lib/storeModule';
const initFiltersStore = storeModule.filter;
import { fetchAdminArea, fetchAreaUser } from '../../api/adminArea/adminArea';
import utils from '@/lib/utils';
const getFilters = utils.getFilters;

const initFilters = () => ({
  filterType: '',

  loginAccount: '',
  name: '',
  cellphone: '',

  areaId: undefined,
});
const filtersStore = initFiltersStore(initFilters, {
  filterStore: state => state.filters,
});

const GET_AREA_LIST_BY_USER = 'GET_AREA_LIST_BY_USER';
const GET_USER_LIST_BY_AREA = 'GET_USER_LIST_BY_AREA';
const TOGGLE_AREA_STATE = 'TOGGLE_AREA_STATE';
const RESET_USER_DATA = 'RESET_USER_DATA';
const RESET_AREA_DATA = 'RESET_AREA_DATA';

const initState = () => ({
  user: {
    adminCellphone: '',
    adminLoginAccount: '',
    adminName: '',
    id: null,
    listAdminArea: [],
  },
  area: {
    hasData: false,
    listUserArea: [],
  },
});

const state = () => ({
  data: initState(),
});

const getters = {
  userData: state => state.data.user,
  areaUserData: state => state.data.area,
};

const actions = {
  fetchAdminArea({ commit, getters }) {
    const filters = getFilters(getters.filters);
    return fetchAdminArea({
      data: { ...filters },
    }).then(res => {
      const data = res.data;
      commit(GET_AREA_LIST_BY_USER, data);
    });
  },
  resetAdminArea({ commit, dispatch }) {
    dispatch('updateFilters', {
      loginAccount: '',
      name: '',
      cellphone: '',
    });
    commit(RESET_USER_DATA);
  },
  fetchAreaUser({ commit, getters }) {
    const filters = getFilters(getters.filters);
    return fetchAreaUser({
      params: { ...filters },
    }).then(res => {
      const data = res.data;
      commit(GET_USER_LIST_BY_AREA, data);
    });
  },
  resetAreaUser({ commit, dispatch }) {
    dispatch('updateFilters', {
      areaId: undefined,
    });
    commit(RESET_AREA_DATA);
  },
};

const mutations = {
  [GET_AREA_LIST_BY_USER]: (state, data) => {
    state.data.user = {
      ...data,
      listAdminArea: data.listAdminArea.map(item => item.areaId),
    };
  },
  [GET_USER_LIST_BY_AREA](state, list) {
    state.data.area.listUserArea = list.map(item => item.id);
    state.data.area.hasData = true;
  },
  [RESET_USER_DATA](state) {
    state.data.user = initState().user;
  },
  [RESET_AREA_DATA](state) {
    state.data.area = initState().area;
  },
};

export default {
  namespaced: true,
  modules: {
    filtersStore,
  },
  state,
  getters,
  actions,
  mutations,
};
