import { getCustomerInfo,fetchAccountLessThanZero } from '@/api/customer/customerInfo';
import utils from '@/lib/utils';
const getFilters = utils.getFilters;
import storeModule from '@/lib/storeModule';
const pagination = storeModule.pagination;
const formatDate = utils.formatDate;

const CUSTOMER_INFO = 'CUSTOMER_INFO';
const CUSTOMERINFOVO = 'CUSTOMERINFOVO';
const SHOWTYPE='SHOWTYPE';
const STORE_QUERY_DATA = 'STORE_QUERY_DATA';
const state = ()=>({
  list: [],
  showType:1,
  filterData:{
    areaId:null,
    customerType:null,
    id:null,
    customerPhone:null,
    customerName:null,
    state:null,
    isFirstRecharge:null,
   //时间选择
   timeSelect: [],
    whetherGo:false,
  }
});

const getters = {
  list: state => state.list,
  customerInfoVo: state => state.customerInfoVo,
  showType: state =>state.showType,
  filterData: state => state.filterData,
};

const actions = {
  getCustomerInfo({ commit, state, dispatch }, entity) {

    const { timeSelect, ...filters } = getFilters(state.filterData);
    if (timeSelect) {
      const [fromDate, toDate] = timeSelect;
      if (fromDate) filters.fromDate = fromDate;
      if (toDate) filters.toDate = formatDate(toDate, 'yyyy-MM-dd') + ' 23:59:59';
    }
    return getCustomerInfo({
      params: {},
      data: {
        pageNum: state.pagination.pageNum,
        pageSize: state.pagination.pageSize,
        ...filters,
        ...entity,
      },
    }).then(response => {
      const { list, ...pagination } = response.data;
      dispatch('updatePagination', pagination);
      commit(CUSTOMER_INFO, list);
      //   commit(CUSTOMERINFOVO, customerInfoVo);
    });
  },
  fetchAccountLessThanZero({ commit, state, dispatch }, entity){
    return fetchAccountLessThanZero({
      params: {
        ...entity,
      }
    });
  },
  updateShowType({ commit },type){

    commit(SHOWTYPE,type)

  },
  storeQueryData({ commit }, entity) {
    commit(STORE_QUERY_DATA, entity);
  },


};

const mutations = {
  [CUSTOMER_INFO](state, list) {
    state.list = list;
  },

  [CUSTOMERINFOVO](state, customerInfoVo) {
    state.customerInfoVo = customerInfoVo;
  },
  [SHOWTYPE](state,showType){
    state.showType=showType;
  },
  [STORE_QUERY_DATA](state, list) {
    state.filterData = {
      ...state.filterData,
      ...list,
    };
  },
};

export default {
  namespaced: true,
  modules: {
    pagination,
  },
  state,
  getters,
  actions,
  mutations,
};
