import storeModule from '@/lib/storeModule';
const pagination = storeModule.pagination;
const initFiltersStore = storeModule.filter;
import utils from '@/lib/utils';
const getFilters = utils.getFilters;
import { fetchFirmwareList } from '@/api/device/firmware';

const GET_FIRMWARE_LIST = 'GET_FIRMWARE_LIST';
const RESET_FIRMWARE_SELECTED = 'RESET_FIRMWARE_SELECTED';
const UPDATE_FIRMWARE_SELECT = 'UPDATE_FIRMWARE_SELECT';

const initFilters = () => ({
  name: '', // 版本号
  enableStatus: '', // 启用状态 1：启用；0：停用
  deviceType: undefined, // 类型id
  timeRange: [],
});
const filtersStore = initFiltersStore(initFilters);

const state = () => ({
  list: [],
});
const getters = {
  firmwareList: state => state.list,
};
const actions = {
  fetchFirmwareList({ dispatch, commit, state, getters }, entity) {
    let filters = getFilters(getters.filters);
    if (filters.timeRange && filters.timeRange.length) {
      const [startDate, endDate] = filters.timeRange;
      if (startDate) {
        filters.startDate = new Date(startDate);
      }
      if (endDate) {
        filters.endDate = new Date(endDate);
      }
    }
    return fetchFirmwareList({
      ...filters,
      ...state.pagination,
      ...entity,
    }).then(res => {
      const { list, ...pagination } = res.data;
      dispatch('updatePagination', pagination);
      commit(GET_FIRMWARE_LIST, list.map(i => ({ ...i, selected: false })));
    });
  },
  updateSelectedState({ commit }, entity) {
    commit(UPDATE_FIRMWARE_SELECT, entity);
  },
  resetSelectedList({ commit }) {
    commit(RESET_FIRMWARE_SELECTED);
  },
};
const mutations = {
  [GET_FIRMWARE_LIST](state, list) {
    state.list = list;
  },
  [UPDATE_FIRMWARE_SELECT](state, { index, value }) {
    state.list = [
      ...state.list.slice(0, index),
      {
        ...state.list[index],
        selected: value,
      },
      ...state.list.slice(index + 1),
    ];
  },
  [RESET_FIRMWARE_SELECTED](state) {
    state.list = state.list.map(i => ({ ...i, selected: false }));
  },
};

export default {
  namespaced: true,
  modules: {
    pagination,
    filtersStore,
  },
  state,
  getters,
  actions,
  mutations,
};
