import storeModule from '@/lib/storeModule';
const pagination = storeModule.pagination;
const initFiltersStore = storeModule.filter;
import utils from '@/lib/utils';
const getFilters = utils.getFilters;
import { fetchEquipmentParamsList } from '@/api/equipmentParamsManagement/equipmentParams';

const GET_EQUIPMENT_PARAMS_LIST = 'GET_EQUIPMENT_PARAMS_LIST';

const initFilters = () => ({
  deviceCode: '',
  deviceType: undefined,
  versionId: undefined,
  paramId: undefined,
  timeRange: [],
});
const filtersStore = initFiltersStore(initFilters);

const state = () => ({
  list: [],
});

const getters = {
  equipmentParamsList: state => state.list,
};
const actions = {
  fetchEquipmentParamsList({ dispatch, commit, state, getters }, entity) {
    let { timeRange, ...filters } = getFilters(getters.filters);
    if (timeRange) {
      const [effectiveAtStart, effectiveAtEnd] = timeRange;
      if (effectiveAtStart) filters.effectiveAtStart = effectiveAtStart;
      if (effectiveAtEnd) filters.effectiveAtEnd = effectiveAtEnd;
    }
    return fetchEquipmentParamsList({
      params: {
        ...filters,
        ...state.pagination,
        ...entity,
      },
    })
      .then(res => {
        const { list, ...pagination } = res.data;
        dispatch('updatePagination', pagination);
        commit(GET_EQUIPMENT_PARAMS_LIST, list);
      })
      .catch(err => {
        console.error(err);
      });
  },
};
const mutations = {
  [GET_EQUIPMENT_PARAMS_LIST](state, list) {
    state.list = list;
  },
};

export default {
  namespaced: true,
  modules: {
    pagination,
    filtersStore,
  },
  state,
  getters,
  actions,
  mutations,
};
