import storeModule from '@/lib/storeModule';
const pagination = storeModule.pagination;
const initFiltersStore = storeModule.filter;
import utils from '@/lib/utils';
const getFilters = utils.getFilters;
import { fetchEquipmentParamsLogList } from '@/api/equipmentParamsManagement/equipmentParamsLog';

const GET_EQUIPMENT_PARAMS_LOG_LIST = 'GET_EQUIPMENT_PARAMS_LOG_LIST';

const initFilters = () => ({
  deviceCode: '',
  deviceType: undefined,
  versionId: undefined,
  paramId: undefined,
  timeRange: [],
  status: undefined,
});
const filtersStore = initFiltersStore(initFilters);

const state = () => ({
  list: [],
});

const getters = {
  paramsLogList: state => state.list,
};
const actions = {
  fetchEquipmentParamsLogList({ dispatch, commit, state, getters }, entity) {
    let { timeRange, ...filters } = getFilters(getters.filters);
    if (timeRange) {
      const [createAtStart, createAtEnd] = timeRange;
      if (createAtStart) filters.createAtStart = createAtStart;
      if (createAtEnd) filters.createAtEnd = createAtEnd;
    }
    return fetchEquipmentParamsLogList({
      params: {
        ...filters,
        ...state.pagination,
        ...entity,
      },
    })
      .then(res => {
        const { list, ...pagination } = res.data;
        dispatch('updatePagination', pagination);
        commit(GET_EQUIPMENT_PARAMS_LOG_LIST, list);
      })
      .catch(err => {
        console.error(err);
      });
  },
};
const mutations = {
  [GET_EQUIPMENT_PARAMS_LOG_LIST](state, list) {
    state.list = list;
  },
};

export default {
  namespaced: true,
  modules: {
    pagination,
    filtersStore,
  },
  state,
  getters,
  actions,
  mutations,
};
