import storeModule from '@/lib/storeModule';
const pagination = storeModule.pagination;
const initFiltersStore = storeModule.filter;
import utils from '@/lib/utils';
const getFilters = utils.getFilters;
import {
  fetchEquipmentList,
  getPositionsList,
} from '@/api/hairDryer/equipment';

const GET_EQUIPMENT_LIST = 'GET_EQUIPMENT_LIST';
const RESET_EQUIPMENT_LIST = 'RESET_EQUIPMENT_LIST';
const GET_POSITION_LIST = 'GET_POSITION_LIST';

const initFilters = () => ({
  operatorId: undefined,
  campusId: undefined,
  equipmentCode: '',
  equipmentAddress: '',
});
const filtersStore = initFiltersStore(initFilters);

const state = () => ({
  list: [],
  positionList: [],
});
const getters = {
  equipmentList: state => state.list,
  positionList: state => state.positionList,
};
const actions = {
  fetchEquipmentList({ dispatch, commit, state, getters }, entity) {
    const filters = getFilters(getters.filters);
    if(entity &&entity.campusId){
      dispatch("updateFilters",{campusId:entity.campusId})
    }

    return fetchEquipmentList({
      ...filters,
      ...state.pagination,
      ...entity,
    }).then(res => {
      const { list, ...pagination } = res.data;
      dispatch('updatePagination', pagination);
      commit(GET_EQUIPMENT_LIST, list);
    });
  },
  rest({ commit, dispatch }) {
    dispatch('resetPagination');
    dispatch('resetFilters');
    commit(RESET_EQUIPMENT_LIST);
  },
  getPositionsList({ commit }, { entity, data }) {
    return getPositionsList(entity)
      .then(res => {
        let list = data ? [...res.data, data] : res.data;
        console.log(list,data);
        list = list&&list.length>0?list.filter(t=>t.campusId==entity.campusId||(data?t.id==data.id:t.campusId==entity.campusId)):[];
        commit(GET_POSITION_LIST, list);
      })
      .catch(err => {
        console.log(err);
        commit(GET_POSITION_LIST, [data]);
      });
  },
  restPositionList({ commit },entity){
    commit(GET_POSITION_LIST, null);
  }
};
const mutations = {
  [GET_EQUIPMENT_LIST](state, list) {
    state.list = list;
  },
  [RESET_EQUIPMENT_LIST](state) {
    state.list = [];
  },
  [GET_POSITION_LIST](state, list) {
    state.positionList = list;
  },
};

export default {
  namespaced: true,
  modules: {
    pagination,
    filtersStore,
  },
  state,
  getters,
  actions,
  mutations,
};
