import storeModule from '@/lib/storeModule';
const pagination = storeModule.pagination;
import { fetchOrderList } from '@/api/hairDryer/order';
const initFiltersStore = storeModule.filter;
import utils from '@/lib/utils';
const getFilters = utils.getFilters;
const formatDate = utils.formatDate;
const GET_ORDER_LIST = 'GET_ORDER_LIST';
const RESET_EQUIPMENT_LIST = 'RESET_EQUIPMENT_LIST';
const initFilters = () => ({
  campusId: undefined,
  equipmentCode: '',
  timeRange: [
    formatDate(new Date(), 'yyyy-MM-dd') + ' 00:00:00',
    formatDate(new Date(), 'yyyy-MM-dd') + ' 23:59:59',
  ],
  customerName: '',
  phone: '',
});
const filtersStore = initFiltersStore(initFilters);


const state = () => ({
  list: [],
});
const getters = {
  orderList: state => state.list,
};
const actions = {
  fetchOrderList({ state, commit, dispatch ,getters}, entity) {
    const { timeRange, ...filters } = getFilters(getters.filters);
    if (timeRange) {
      const [startTime, endTime] = timeRange;
      if (startTime) filters.startTime = startTime;
      if (endTime) filters.endTime = endTime;
    }
    //const filters = getFilters(getters.filters);
    return fetchOrderList({
     // campusId: state.campusId,
     ...filters,
      ...state.pagination,
      ...entity,
    }).then(res => {
      const {
        dataList: { list, ...pagination },
        groupData,
      } = res.data;
      dispatch('updatePagination', pagination);
      commit(GET_ORDER_LIST, list);
      return groupData;
    });
  },
  rest({ commit, dispatch }) {
    dispatch('resetPagination');
    dispatch('resetFilters');
    commit(RESET_EQUIPMENT_LIST);
  },
};
const mutations = {
  [GET_ORDER_LIST](state, list) {
    state.list = list;
  },
  [RESET_EQUIPMENT_LIST](state) {
    state.list = [];
  },
};

export default {
  namespaced: true,
  modules: {
    pagination,
    filtersStore,
  },
  state,
  getters,
  actions,
  mutations,
};
