import storeModule from '@/lib/storeModule';
const pagination = storeModule.pagination;
import { fetchRateList, fetchRateOptions } from '@/api/hairDryer/rate';
const initFiltersStore = storeModule.filter;
import utils from '@/lib/utils';
const getFilters = utils.getFilters;

const GET_RATE_LIST = 'GET_RATE_LIST';
const GET_RATE_OPTIONS = 'GET_RATE_OPTIONS';
const RESET_RATE_OPTIONS = 'RESET_RATE_OPTIONS';
const RESET_EQUIPMENT_LIST = 'RESET_EQUIPMENT_LIST';
const initFilters = () => ({
  schoolId: '',
  operatorId: undefined,
  campusId: undefined,

});
const filtersStore = initFiltersStore(initFilters);

const state = () => ({
  list: [],
  options: [],
});
const getters = {
  rateList: state => state.list,
  rateOptions: state => state.options,
};
const actions = {
  fetchRateList({ dispatch, state, commit,getters }, entity) {
    const filters = getFilters(getters.filters);
    if(entity &&entity.campusId){
      dispatch("updateFilters",{campusId:entity.campusId})
    }
    return fetchRateList({
      // campusId: state.campusId,
      ...filters,
      ...state.pagination,
      ...entity,
    }).then(res => {
      const { list, ...pagination } = res.data;
      dispatch('updatePagination', pagination);
      commit(GET_RATE_LIST, list);
    });
  },
  fetchRateOptions({ commit }, entity) {
    commit(RESET_RATE_OPTIONS);
    return fetchRateOptions(entity).then(res => {
      commit(GET_RATE_OPTIONS, res.data);
    });
  },
  rest({ commit, dispatch }) {
    dispatch('resetPagination');
    dispatch('resetFilters');
    commit(RESET_EQUIPMENT_LIST);
  },
};
const mutations = {
  [GET_RATE_LIST](state, list) {
    state.list = list;
  },
  [RESET_RATE_OPTIONS](state) {
    state.options = [];
  },
  [GET_RATE_OPTIONS](state, list) {
    state.options = list;
  },
  [RESET_EQUIPMENT_LIST](state) {
    state.list = [];
  },
};

export default {
  namespaced: true,
  modules: {
    pagination,
    filtersStore,
  },
  state,
  getters,
  actions,
  mutations,
};
