import storeModule from '@/lib/storeModule';
const pagination = storeModule.pagination;
const initFiltersStore = storeModule.filter;
import utils from '@/lib/utils';
const getFilters = utils.getFilters;
import {
  fetchDisableTimeList,
  fetchConfigDevice,
} from '@/api/hairDryer/timeConfig';

const GET_TIME_LIST = 'GET_TIME_LIST';
const GET_DEVICE_LIST = 'GET_DEVICE_LIST';
const ADD_DEVICE_LIST = 'ADD_DEVICE_LIST';

const initFilters = () => ({
  campusId: undefined,
  name: '',
  code: '',
});
const filtersStore = initFiltersStore(initFilters);

const state = () => ({
  list: [],
  deviceList: [],
});
const getters = {
  timeList: state => state.list,
  deviceList: state => state.deviceList,
};
const actions = {
  fetchDisableTimeList({ commit, dispatch, state, getters }, entity) {
    const filters = getFilters(getters.filters);
    return fetchDisableTimeList({
      ...filters,
      ...state.pagination,
      ...entity,
    }).then(res => {
      const { list, ...pagination } = res.data;
      dispatch('updatePagination', pagination);
      commit(GET_TIME_LIST, list);
    });
  },
  fetchConfigDevice({ commit }, entity) {
    return fetchConfigDevice({
      params: entity,
    }).then(res => {
      const list = res.data;
      commit(GET_DEVICE_LIST, list);
    });
  },
};
const mutations = {
  [GET_TIME_LIST]: (state, list) => {
    state.list = list;
  },
  [GET_DEVICE_LIST]: (state, list) => {
    state.deviceList = list.map(item => ({
      ...item,
      text: `${item.deviceCode} - ${item.position ? item.position : ''}`,
    }));
  },
};

export default {
  namespaced: true,
  modules: {
    pagination,
    filtersStore,
  },
  state,
  getters,
  actions,
  mutations,
};
