export default {
  data() {
    return {
      stateOptions: [{ value: 0, name: '上架' }, { value: 1, name: '下架' }],
      logOptions: [{ value: 0, name: '否' }, { value: 1, name: '是' }],
      dialogConfigVisible: false,
    };
  },
  methods: {
    getStateName(val) {
      let item = this.stateOptions.find(item => item.value === val);
      return item ? item.name : '-';
    },
    getLogName(val) {
      let item = this.logOptions.find(item => item.value === val);
      return item ? item.name : '-';
    },
    initSelected() {
      return {
        id: null,
        comment: '',
        createAt: '',
        developer: '',
        domainName: '',
        handoverPerson: '',
        interfaceCode: '',
        interfaceMethod: '',
        interfaceName: '',
        interfaceParameter: '',
        interfaceType: '',
        interfaceUri: '',
        isDown: null,
        isLog: null,
        iteratorInterface: '',
      };
    },
    showEditDialog(type, data) {
      this.editType = type;
      if (type === 0) {
        this.selected = this.initSelected();
      } else if (type === 1) {
        this.selected = {
          ...data,
        };
      }
      this.dialogEditVisible = true;
    },
    validateSelected() {
      if (!this.selected.interfaceCode) {
        this.$message.error('请输入接口编码');
        return;
      }
      if (!this.selected.interfaceName) {
        this.$message.error('请输入接口名称');
        return;
      }
      if (!this.selected.interfaceUri) {
        this.$message.error('请输入资源地址');
        return;
      }
      if (!this.selected.domainName) {
        this.$message.error('请输入访问域名');
        return;
      }
      if (!this.selected.interfaceMethod) {
        this.$message.error('请输入所属功能');
        return;
      }
      if (!this.selected.developer) {
        this.$message.error('请输入开发者');
        return;
      }
      // if (!this.selected.iteratorInterface) {
      //   this.$message.error('请输入迭代接口');
      //   return;
      // }
      if (!this.selected.handoverPerson) {
        this.$message.error('请输入交接人');
        return;
      }
      if (!this.selected.interfaceParameter) {
        this.$message.error('请输入接口参数');
        return;
      }
      // if (!this.selected.comment) {
      //   this.$message.error('请输入接口说明');
      //   return;
      // }
      return true;
    },
    updateSelected() {
      const type = this.editType;
      if (this.validateSelected()) {
        if (type === 0) {
          const entity = {
            ...this.selected,
          };
          this.addInterface(entity)
            .then(res => {
              this.$message.success(res.msg || '新增成功！');
              this.fetchList();
              this.dialogEditVisible = false;
            })
            .catch(err => {
              console.error(err);
            });
        } else if (type === 1) {
          const entity = {
            ...this.selected,
          };
          this.updateInterface(entity)
            .then(res => {
              this.$message.success(res.msg || '更新成功！');
              this.fetchList();
              this.dialogEditVisible = false;
            })
            .catch(err => {
              console.error(err);
            });
        }
      }
    },
    showConfigDialog(data) {
      this.selected = {
        ...data,
      };
      this.dialogConfigVisible = true;
    },
    resetConfigDialog(done) {
      this.configFilters = {};
      if (typeof this.initSelected === 'function') {
        this.selected = this.initSelected();
      } else {
        this.selected = {};
      }
      done && typeof done == 'function'
        ? done()
        : (this.dialogConfigVisible = false);
    },
    // 配置内方法
    fetchConfigList(entity) {
      const filters = this.$getFilters(this.configFilters);
      this.fetchDetailList({
        ...filters,
        interfaceId: this.selected.id,
        ...entity,
      });
    },
    configChangePage(index) {
      this.fetchConfigList({
        pageNum: index,
      });
    },
    toggleInterfaceState(data) {
      const id = data.id;
      const state = data.isDown === 0 ? 1 : 0;
      this.$mdAlert
        .confirm(
          `是否确认${state === 0 ? '上架' : '下架'} ${
            data.interfaceName
          } 接口？`
        )
        .then(action => {
          this.toggleState({
            data: {
              id,
              isDown: state,
            },
          })
            .then(res => {
              this.$message.success(
                res.msg || `${state === 0 ? '上架' : '下架'}成功！`
              );
              this.fetchList();
            })
            .catch(err => {
              console.error(err);
            });
        });
    },
    delLogUser(data) {
      this.$mdAlert.confirm('是否确认删除配置？').then(action => {
        this.delLogUserHandle(data)
          .then(res => {
            this.$message.success(res.msg || '删除成功！');
            this.fetchConfigList();
          })
          .catch(err => {
            console.error(err);
          });
      });
    },
    toggleLogUserState(entity) {
      this.$mdAlert
        .confirm(`是否确认${entity.isClose === 0 ? '开启' : '关闭'}配置？`)
        .then(action => {
          this.toggleLogUserHandle(entity)
            .then(res => {
              this.fetchConfigList();
              this.$message.success(res.msg || '操作成功');
            })
            .catch(err => {
              console.error(err);
            });
        });
    },
  },
};
