import { fetchMenuTree } from '@/api/menu/menu';

const GET_MENU_TREE = 'GET_MENU_TREE';
const UPDATE_SELECT = 'UPDATE_SELECT';
const RESET_SELECT = 'RESET_SELECT';
import storeModule from '@/lib/storeModule';
const initFiltersStore = storeModule.filter;
import utils from '@/lib/utils';
const getFilters = utils.getFilters;

const initFilters = () => ({
  menuCode: null,
  menuName: null,

});
const filtersStore = initFiltersStore(initFilters);


const findSelectedItem = (list, id) => {
  let res = null;
  list.find(item => {
    if (item.id === id) {
      res = item;
      return true;
    }
    if (item.childs && item.childs.length) {
      let childsItem = findSelectedItem(item.childs, id);
      if (childsItem) {
        res = childsItem;
        return true;
      }
      return false;
    }
    return false;
  });
  return res;
};

const initSelected = () => ({
  parentName: '',
  menuName: '',
  state: '',
  menuLevel: '',
  menuLink: '',
  listMenuButtonVo: [],
  menuPicSmall: '',
  menuPicBig: '',
  createAt: '',
  creater: '',
  updateAt: '',
  ip: '',
  updater: '',
});

const state = () => ({
  list: [],
  lastSelected: [],
  selected: initSelected(),
});

const getters = {
  listData: state => state.list,
  seletedData: state => state.selected,
};

const actions = {
  fetchMenuTree({ commit,getters }, entity) {
    let filters = getFilters(getters.filters);
    return fetchMenuTree({
      data: {
        ...filters,
        ...entity,
      },
    }).then(res => {
      let list = res.data;
      commit(GET_MENU_TREE, list);
    });
  },
  selectTreeNode({ commit }, data) {
    if (data) {
      commit(UPDATE_SELECT, data);
    } else {
      commit(RESET_SELECT);
    }
  },
  resetSelect({ commit }) {
    commit(RESET_SELECT);
  },
};

const mutations = {
  [GET_MENU_TREE]: (state, list) => {
    state.list = list;
    if (state.selected.id) {
      state.selected = findSelectedItem(list, state.selected.id);
    }
  },
  [UPDATE_SELECT]: (state, data) => {
    state.selected = data;
  },
  [RESET_SELECT]: state => {
    state.selected = initSelected();
  },
};

export default {
  namespaced: true,
  modules: {
    filtersStore,
  },
  state,
  getters,
  actions,
  mutations,
};
