import {
  fetchConsumeOrder,
  getKindBean,
} from '../../../api/order/consumeOrder';
import {
  fetchPaymentList,
  fetchServiceList,
  fetchRelation
} from '../../../api/base/index';
import storeModule from '@/lib/storeModule';
const pagination = storeModule.pagination;
const formatDate = utils.formatDate;
import utils from '@/lib/utils';
const getFilters = utils.getFilters;

const GET_ORDER_LIST = 'GET_ORDER_LIST';
const GET_SERVICE = 'GET_SERVICE';
const STORE_QUERY_DATA = 'STORE_QUERY_DATA';
const GET_ALL_PAYMENTS = 'GET_ALL_PAYMENTS';
const GET_RELATION = 'GET_RELATION';
const SERVICE_FOR_CHOSE = 'SERVICE_FOR_CHOSE';

// let newDate = new Date();

const state = () => ({
  list: [],
  servicelist: [],
  Relations: [],
  NowRelation: [],
  consumeOrderGroupVo: {
    actualMoney: 0,
    deductionMoney: 0,
    payAccount: 0,
    payableMoney: 0,
    unPayAccount: 0,
    deductionBean: 0,
  },
  listServices: [],
  listPayments: [],
  ServiceOptions: [],
  storeData: {
    timeRange: [
      formatDate(new Date(), 'yyyy-MM-dd') + ' 00:00:00',
      formatDate(new Date(), 'yyyy-MM-dd') + ' 23:59:59',
    ],
    dateRange: [],
    areaId: null,
    serviceId: null,
    equipmentPosition: null,
    equipmentNum: null,
    payType: null,
    customerId: null,
    customerCellphone: null,
    customerName: '',
    orderNumber: null,
    orderState: null,
    whetherGo: false,
  },
});

const getters = {
  listPayments: state => state.listPayments,
  listData: state => state.list,
  consumeOrderGroupVo: state => state.consumeOrderGroupVo,
  listServices: state => state.listServices,
  Relations: state => state.Relations,
  storeData: state => state.storeData,
  ServiceOptions: state => state.ServiceOptions,
};

const actions = {
  fetchConsumeOrder({
    state,
    commit,
    dispatch
  }, entity) {
    const {
      timeRange,
      dateRange,
      ...filters
    } = getFilters(state.storeData);
    if (dateRange) {
      const [startDate, endDate] = dateRange;
      if (startDate) filters.startDate = startDate;
      if (endDate) filters.endDate = formatDate(endDate, 'yyyy-MM-dd') + ' 23:59:59';
    }
    if (timeRange) {
      const [fromDate, toDate] = timeRange;
      if (fromDate) filters.fromDate = fromDate;
      if (toDate) filters.toDate =  formatDate(toDate, 'yyyy-MM-dd') + ' 23:59:59';
    }
    return fetchConsumeOrder({
      data: {
        pageNum: state.pagination.pageNum,
        pageSize: state.pagination.pageSize,
        ...filters,
        ...entity,
      },
    }).then(res => {
      const {
        list,
        ...pagination
      } = res.data;
      let consumeOrderGroupVo = res.consumeOrderGroupVo;
      if (!consumeOrderGroupVo) {
        consumeOrderGroupVo = {
          actualMoney: 0,
          deductionMoney: 0,
          payAccount: 0,
          payableMoney: 0,
          unPayAccount: 0,
          deductionBean: 0,
        };
      }
      dispatch('updatePagination', pagination);
      commit(GET_ORDER_LIST, {
        list,
        consumeOrderGroupVo,
      });
    });
  },
  getKindBean({
    state,
    commit,
    dispatch
  }, entity) {
    return getKindBean({
      params: {
        ...entity,
      },
    });
  },
  fetchServiceList({
    state,
    commit,
    dispatch
  }, entity) {
    return fetchServiceList({
      params: {
        ...entity,
      },
    }).then(res => {
      const list = res.selfService;
      // const servicelist = [];
      if (list) {
        this.servicelist = list.filter(t => t.id != 0 && t.id != 1);
      }
      commit(SERVICE_FOR_CHOSE, this.servicelist);
      commit(GET_SERVICE, list);
    });
  },
  fetchPaymentList({
    state,
    commit,
    dispatch
  }, entity) {
    return fetchPaymentList({
      params: {
        ...entity,
      },
    }).then(res => {
      const list = res.data;
      commit(GET_ALL_PAYMENTS, list);
    });
  },
  // getDevicePosition({ state, commit, dispatch }, entity) {
  //   return listDevicePosition({
  //     params: {
  //       ...entity,
  //     },
  //     notLoading: true,
  //   });
  // },
  fetchRelation({
    state,
    commit,
    dispatch
  }, entity) {
    return fetchRelation({
      params: {
        ...entity,
      },
    }).then(res => {
      const list = res.data;
      this.NowRelation = list;
      commit(GET_RELATION, list);
    })
  },
  storeQueryData({
    commit
  }, entity) {
    //--------------
    if (entity.hasOwnProperty("areaId")) {
      if (!entity.areaId) {
        commit(SERVICE_FOR_CHOSE, this.servicelist);
      } else {
        let v = [];
        if (this.NowRelation) {
          let x = this.NowRelation.filter(t => t.areaId == entity.areaId && t.serviceId != 0 && t.serviceId != 1);
          let nowIds = x ? x.map(y => y.serviceId) : [];
          if (nowIds && this.servicelist) {
            v = this.servicelist.filter(t => nowIds.some(x => x == t.id));
          }
        }
        commit(SERVICE_FOR_CHOSE, v);
        //清空已选的服务
        let ns = {serviceId:null}
        commit(STORE_QUERY_DATA,ns);
      }
    }
    //时间选择
    if(entity.hasOwnProperty("timeRange")){
      if(entity.timeRange[1]&&entity.timeRange[0]){
        const startTime = new Date(entity.timeRange[0]).getTime();
        const endTime = new Date(entity.timeRange[1]).getTime();
        if(startTime>endTime){
          entity.timeRange[0]="";
        }
      }
    }
    if(entity.hasOwnProperty("dateRange")){
      if(entity.dateRange[1]&&entity.dateRange[0]){
        const startTime = new Date(entity.dateRange[0]).getTime();
        const endTime = new Date(entity.dateRange[1]).getTime();
        if(startTime>endTime){
          entity.dateRange[0]="";
        }
      }
    }
    //--------------
    commit(STORE_QUERY_DATA, entity);
  },
};

const mutations = {
  [GET_ORDER_LIST]: (state, {
    list,
    consumeOrderGroupVo
  }) => {
    state.list = list;
    state.consumeOrderGroupVo = consumeOrderGroupVo;
  },
  [GET_SERVICE]: (state, list) => {
    state.listServices = list;
  },
  [GET_ALL_PAYMENTS]: (state, list) => {
    state.listPayments = list;
  },
  [GET_RELATION]: (state, list) => {
    state.Relations = list;
  },
  [SERVICE_FOR_CHOSE]: (state, list) => {
    state.ServiceOptions = list;
  },
  [STORE_QUERY_DATA](state, list) {
    state.storeData = {
      ...state.storeData,
      ...list,
    };
  },
};

export default {
  namespaced: true,
  modules: {
    pagination,
  },
  state,
  getters,
  actions,
  mutations,
};
