import { getFailedOrder } from '@/api/order/failedOrder';
const formatDate = utils.formatDate;
import utils from '@/lib/utils';
const getFilters = utils.getFilters;
import storeModule from '@/lib/storeModule';
const pagination = storeModule.pagination;

const GET_FAILED_ORDER = 'GET_FAILED_ORDER';
const STORE_QUERY_DATA = 'STORE_QUERY_DATA';

const state = () => ({
  list: [],
  storeData: {
    timeRange: [
      formatDate(new Date(), 'yyyy-MM-dd')+' 00:00:00',
      formatDate(new Date(), 'yyyy-MM-dd') + ' 23:59:59',
    ],
    //区域
    areaId: null,
    //电话
    customerPhone: '',
    //姓名
    customerName: '',
    orderNum: '',
    fromAmount: null,
    toAmount: null,
    payType: '',
    customerId: null,
    whetherGo: false,
  },
});

const getters = {
  list: state => state.list,
  storeData: state => state.storeData,
};

const actions = {
  getFailedOrder({ commit, state, dispatch }, entity) {
    const { timeRange, ...filters } = getFilters(state.storeData);
    if (timeRange) {
      const [startTime, endTime] = timeRange;
      if (startTime) filters.startTime = startTime;
      if (endTime) filters.endTime = formatDate(endTime, 'yyyy-MM-dd') + ' 23:59:59';
    }
    if(filters.payType){
      let x = filters.payType;
      filters.payType=[];
      filters.payType[0]=x;
      // console.log("萌萌");
    }
    return getFailedOrder({
      data: {
        ...state.pagination,
        ...filters,
        ...entity,
      },
    }).then(response => {
      const { list, ...pagination } = response.data;

      dispatch('updatePagination', pagination);
      commit(GET_FAILED_ORDER, list);
    });
  },
  storeQueryData({ state, commit, dispatch }, entity) {
    commit(STORE_QUERY_DATA, entity);
  },
};

const mutations = {
  [GET_FAILED_ORDER](state, list) {
    state.list = list;
  },
  [STORE_QUERY_DATA](state, list) {
    state.storeData = {
      ...state.storeData,
      ...list,
    };
  },
};

export default {
  namespaced: true,
  modules: {
    pagination,
  },
  state,
  getters,
  actions,
  mutations,
};
