import { getGiveBean } from '@/api/order/giveBean';
import { fetchServiceList } from '@/api/base/index';
const formatDate = utils.formatDate;
import utils from '@/lib/utils';
const getFilters = utils.getFilters;
import storeModule from '@/lib/storeModule';
const pagination = storeModule.pagination;

const GIVE_BEAN_LIST = 'GIVE_BEAN_LIST';
const GIVE_BEAN_GROUP_VO = 'GIVE_BEAN_GROUP_VO';
const SERVICE_TYPE_LIST = 'SERVICE_TYPE_LIST';
const STORE_QUERY_DATA ='STORE_QUERY_DATA';
// let newDate = new Date();

const state = () =>( {
  list: [],
  giveBeanGroupVo: {
    afterCount: 0,
  },
  listServiceType: [],
  storeData: {
    timeRange: [
      formatDate(new Date(), 'yyyy-MM-dd') + ' 00:00:00',
      formatDate(new Date(), 'yyyy-MM-dd') + ' 23:59:59',
    ],
    areaId: null,
    //豆类型
    serviceId: null,
    //电话
    customerCellphone: '',
    //姓名
    customerName: '',
    customerId:null,
    //赠送类型
    giveType: null,
    whetherGo:false,
  },
});

const getters = {
  list: state => state.list,
  giveBeanGroupVo: state => state.giveBeanGroupVo,
  listServiceType: state => state.listServiceType,
  storeData:state => state.storeData,
};

const actions = {
  getGiveBean({ commit, state, dispatch }, entity) {
    const { timeRange, ...filters } = getFilters(state.storeData);
    if(timeRange){
      const [startTime, endTime] = timeRange;
      if (startTime) filters.startTime = startTime;
      if (endTime) filters.endTime = formatDate(endTime, 'yyyy-MM-dd') + ' 23:59:59';
    }
    return getGiveBean({
      data: {
        pageNum: state.pagination.pageNum,
        pageSize: state.pagination.pageSize,
        ...filters,
        ...entity,
      },
    }).then(response => {
      const {
        page: { list, ...pagination },
        giveBeanGroupVo,
      } = response.data;
      dispatch('updatePagination', pagination);
      commit(GIVE_BEAN_LIST, list);
      commit(GIVE_BEAN_GROUP_VO, giveBeanGroupVo);
    });
  },
  getServiceList({ commit, state, dispatch }, entity) {
    return fetchServiceList({
      params: {},
    }).then(response => {
      const { selfService } = response;
      const serviceList = [];
      selfService.filter(service => {
        if (
          (service.serviceType === "1" || service.serviceType === "3") && service.id != 0
        ) {
          serviceList.push(service);
        }
      });
      console.log(serviceList);
      commit(SERVICE_TYPE_LIST, serviceList);
    });
  },
  storeQueryData({
    state,
    commit,
    dispatch
  }, entity) {
    commit(STORE_QUERY_DATA, entity);
  },
};

const mutations = {
  [GIVE_BEAN_LIST](state, list) {
    state.list = list;
  },

  [GIVE_BEAN_GROUP_VO](state, giveBeanGroupVo) {
    state.giveBeanGroupVo = giveBeanGroupVo;
  },

  [SERVICE_TYPE_LIST](state, listServiceType) {
    state.listServiceType = listServiceType;
  },
  [STORE_QUERY_DATA](state, list) {
    state.storeData = {
      ...state.storeData,
      ...list
    };
  },
};

export default {
  namespaced: true,
  modules: {
    pagination,
  },
  state,
  getters,
  actions,
  mutations,
};
