import {
  getPaymentConsume
} from '@/api/order/paymentConsume';
import {
  fetchPaymentList,
  fetchServiceList,
  fetchRelation
} from '../../../api/base/index';
const formatDate = utils.formatDate;
import utils from '@/lib/utils';
const getFilters = utils.getFilters;
import storeModule from '@/lib/storeModule';
const pagination = storeModule.pagination;

const paymentConsume_LIST = 'paymentConsume_LIST';
const paymentConsume_GROUP_VO = 'paymentConsume_GROUP_VO';
const STORE_QUERY_DATA = 'STORE_QUERY_DATA';
const GET_ALL_PAYMENTS = 'GET_ALL_PAYMENTS';
const GET_RELATION = 'GET_RELATION';
const SERVICE_FOR_CHOSE = 'SERVICE_FOR_CHOSE';
// let newDate = new Date();
const state = () => ({
  list: [],
  paymentConsumeGroupVo: {
    money: 0,
    beanCount: 0,
  },
  listPayments: [],
  servicelist: [],
  Relations: [],
  NowRelation: [],
  ServiceOptions: [],
  storeData: {
    timeRange: [
      formatDate(new Date(), 'yyyy-MM-dd') + ' 00:00:00',
      formatDate(new Date(), 'yyyy-MM-dd') + ' 23:59:59',
    ],
    dateRange: [],
    customerId: null,
    areaId: null,
    serviceId: null,
    equipmentPosition: null,
    equipmentNum: null,
    payType: null,
    customerCellphone: null,
    customerName: null,
    orderNumber: null,
    consumeType: null,
    whetherGo: false,
  },
});

const getters = {
  list: state => state.list,
  paymentConsumeGroupVo: state => state.paymentConsumeGroupVo,
  storeData: state => state.storeData,
  listPayments: state => state.listPayments,
  Relations: state => state.Relations,
  ServiceOptions: state => state.ServiceOptions,
};

const actions = {
  getPaymentConsume({
    commit,
    state,
    dispatch
  }, entity) {
    const {
      timeRange,
      dateRange,
      ...filters
    } = getFilters(state.storeData);
    if (dateRange) {
      const [startDate, endDate] = dateRange;
      if (startDate) filters.startDate = startDate;
      if (endDate) filters.endDate = formatDate(endDate, 'yyyy-MM-dd') + ' 23:59:59';
    }
    if (timeRange) {
      const [startTime, endTime] = timeRange;
      if (startTime) filters.startTime = startTime;
      if (endTime) filters.endTime = formatDate(endTime, 'yyyy-MM-dd') + ' 23:59:59';
    }
    return getPaymentConsume({
      data: {
        pageNum: state.pagination.pageNum,
        pageSize: state.pagination.pageSize,
        ...filters,
        ...entity,
      },
    }).then(response => {
      const {
        page: {
          list,
          ...pagination
        },
        paymentConsumeGroupVo,
      } = response.data;

      dispatch('updatePagination', pagination);
      commit(paymentConsume_LIST, list);
      commit(paymentConsume_GROUP_VO, paymentConsumeGroupVo);
    });
  },
  fetchPaymentList({
    state,
    commit,
    dispatch
  }, entity) {
    return fetchPaymentList({
      params: {
        ...entity,
      },
    }).then(res => {
      const list = res.data;
      commit(GET_ALL_PAYMENTS, list);
    });
  },
  fetchServiceList({
    state,
    commit,
    dispatch
  }, entity) {
    return fetchServiceList({
      params: {
        ...entity,
      },
    }).then(res => {
      const list = res.selfService;
      // const servicelist = [];
      if (list) {
        this.servicelist = list.filter(t => t.id != 0 && t.id != 1);
      }
      commit(SERVICE_FOR_CHOSE, this.servicelist);
      // commit(GET_SERVICE, list);
    });
  },
  fetchRelation({
    state,
    commit,
    dispatch
  }, entity) {
    return fetchRelation({
      params: {
        ...entity,
      },
    }).then(res => {
      const list = res.data;
      this.NowRelation = list;
      commit(GET_RELATION, list);
    })
  },
  storeQueryData({
    state,
    commit,
    dispatch
  }, entity) {
    //--------------
    if (entity.hasOwnProperty("areaId")) {
      if (!entity.areaId) {
        commit(SERVICE_FOR_CHOSE, this.servicelist);
      } else {
        let v = [];
        if (this.NowRelation) {
          let x = this.NowRelation.filter(t => t.areaId == entity.areaId && t.serviceId != 0 && t.serviceId != 1);
          let nowIds = x ? x.map(y => y.serviceId) : [];
          if (nowIds && this.servicelist) {
            v = this.servicelist.filter(t => nowIds.some(x => x == t.id));
          }
        }
        commit(SERVICE_FOR_CHOSE, v);
        //清空已选的服务
        let ns = {
          serviceId: null
        }
        commit(STORE_QUERY_DATA, ns);
      }
    }
    //时间选择
    if (entity.hasOwnProperty("timeRange")) {
      if (entity.timeRange[1] && entity.timeRange[0]) {
        const startTime = new Date(entity.timeRange[0]).getTime();
        const endTime = new Date(entity.timeRange[1]).getTime();
        if (startTime > endTime) {
          entity.timeRange[0] = "";
        }
      }
    }
    if(entity.hasOwnProperty("dateRange")){
      if(entity.dateRange[1]&&entity.dateRange[0]){
        const startTime = new Date(entity.dateRange[0]).getTime();
        const endTime = new Date(entity.dateRange[1]).getTime();
        if(startTime>endTime){
          entity.dateRange[0]="";
        }
      }
    }
    //--------------
    commit(STORE_QUERY_DATA, entity);
  },
};

const mutations = {
  [paymentConsume_LIST](state, list) {
    state.list = list;
  },
  [STORE_QUERY_DATA](state, list) {
    state.storeData = {
      ...state.storeData,
      ...list,
    };
  },
  [GET_RELATION]: (state, list) => {
    state.Relations = list;
  },
  [SERVICE_FOR_CHOSE]: (state, list) => {
    state.ServiceOptions = list;
  },
  [GET_ALL_PAYMENTS]: (state, list) => {
    state.listPayments = list;
  },
  [paymentConsume_GROUP_VO](state, paymentConsumeGroupVo) {
    state.paymentConsumeGroupVo = paymentConsumeGroupVo;
  },
};

export default {
  namespaced: true,
  modules: {
    pagination,
    // initFiltersStore,
  },
  state,
  getters,
  actions,
  mutations,
};
