import storeModule from '@/lib/storeModule';
const pagination = storeModule.pagination;
import { fetchAccountList } from '@/api/shower/account';
import utils from '@/lib/utils';
const getFilters = utils.getFilters;
const initFiltersStore = storeModule.filter;

const GET_ACCOUNT_LIST = 'GET_ACCOUNT_LIST';
const RESET_EQUIPMENT_LIST = 'RESET_EQUIPMENT_LIST';

const initFilters = () => ({
  campusId: null,
  account: null,
  status: null,
});
const filtersStore = initFiltersStore(initFilters);

const state = () => ({
  list: [],
});
const getters = {
  accountList: state => state.list,
};
const actions = {
  fetchAccountList({ dispatch, state, commit, getters }, entity) {
    const filters = getFilters(getters.filters);
    if (entity && entity.campusId) {
      dispatch('updateFilters', { campusId: entity.campusId });
    }

    return fetchAccountList({
      ...filters,
      ...state.pagination,
      ...entity,
    }).then(res => {
      const { list, ...pagination } = res.data;
      dispatch('updatePagination', pagination);
      commit(GET_ACCOUNT_LIST, list);
    });
  },
  rest({ commit, dispatch }) {
    dispatch('resetPagination');
    dispatch('resetFilters');
    commit(RESET_EQUIPMENT_LIST);
  },
};
const mutations = {
  [GET_ACCOUNT_LIST](state, list) {
    state.list = list;
  },
  [RESET_EQUIPMENT_LIST](state) {
    state.list = [];
  },
};

export default {
  namespaced: true,
  modules: {
    pagination,
    filtersStore,
  },
  state,
  getters,
  actions,
  mutations,
};
