import {
  queryPage,
  addEntity,
  updateEntity,
  deleteEntity,
  getDetail,
  lockEntity,
} from '../../api/SmaproPrepayConfig.js';

import storeModule from '../../lib/storeModule';
import utils from '../../lib/utils';
const pagination = storeModule.pagination;
const initFiltersStore = storeModule.filter;
const getFilters = utils.getFilters;
const formatDate = utils.formatDate;

const GET_ROLE_LIST = 'GET_ROLE_LIST';
const DETAIL_OPER_RECORD = 'DETAIL_OPER_RECORD'; //操作记录
const DETAIL_LIST = 'DETAIL_LIST'; //列表详情

const initFilters = () => ({
  operateId: null,
  serviceId: null,
  timeRange: [],
  isOpen: null,
  operator: '',
});
const filtersStore = initFiltersStore(initFilters);

const state = () => ({
  list: [],
  detailOperRecord: [],
  detailList: [],
});

const getters = {
  listData: state => state.list,
  detailOperRecord: state => state.detailOperRecord,
  detailList: state => state.detailList,
};

const actions = {
  fetchLists({ state, commit, dispatch, getters }, entity) {
    // let filters = getFilters(getters.filters);
    const { timeRange, ...filters } = getFilters(getters.filters);
    if (timeRange) {
      const [fromDate, toDate] = timeRange;
      if (fromDate) filters.startTime = fromDate;
      if (toDate) filters.endTime = formatDate(toDate, 'yyyy-MM-dd 23:59:59');
    }
    return queryPage({
      data: {
        pageNum: state.pagination.pageNum,
        pageSize: state.pagination.pageSize,
        ...filters,
        ...entity,
      },
    }).then(res => {
      const { list, ...pagination } = res.data;
      dispatch('updatePagination', pagination);
      commit(GET_ROLE_LIST, list);
    });
  },
  addEntitys({ state, commit, dispatch }, entity) {
    return addEntity({
      data: {
        ...entity,
      },
    });
  },
  updateEntitys({ state, commit, dispatch }, entity) {
    return updateEntity({
      data: {
        ...entity,
      },
    });
  },
  lockEntitys({ state, commit, dispatch }, entity) {
    return lockEntity({
      params: {
        ...entity,
      },
    });
  },

  deleteEntitys({ state, commit, dispatch }, entity) {
    return deleteEntity({
      params: {
        ...entity,
      },
    });
  },

  getDetails({ state, commit, dispatch }, entity) {
    return getDetail({
      params: {
        ...entity,
      },
    }).then(res => {
      const { opertorRecord, detail } = res.data;
      commit(DETAIL_OPER_RECORD, opertorRecord);
      commit(DETAIL_LIST, detail);
    });
  },
};

const mutations = {
  [GET_ROLE_LIST]: (state, list) => {
    state.list = list;
  },

  [DETAIL_OPER_RECORD]: (state, detailOperRecord) => {
    state.detailOperRecord = detailOperRecord;
  },
  [DETAIL_LIST]: (state, detailList) => {
    state.detailList = detailList;
  },
};

export default {
  namespaced: true,
  modules: {
    pagination,
    filtersStore,
  },
  state,
  getters,
  actions,
  mutations,
};
