import storeModule from '@/lib/storeModule';
const pagination = storeModule.pagination;
import utils from '@/lib/utils';
const getFilters = utils.getFilters;
const formatDate = utils.formatDate;
import { queryPage } from '../../api/SmaproRefundOrder';

const GET_ROLE_LIST = 'GET_ROLE_LIST';
const MONEY = 'MONEY'; //钱汇总
const STORE_QUERY_DATA = 'STORE_QUERY_DATA';
const state = () => ({
  list: [],
  money: null,
  storeData:{
    operateId:null,
    serviceId:null,
    refundType:null,
    customerId:null,
    equipmentNum:null,
    equipmentPos:null,
    orderNumber:null,
    refundOrderNum:null,
    timeRange:[
      formatDate(new Date(), 'yyyy-MM-dd') + ' 00:00:00',
      formatDate(new Date(), 'yyyy-MM-dd') + ' 23:59:59',
    ],
  },
});

const getters = {
  list: state => state.list,
  money: state => state.money,
  storeData: state => state.storeData,
};

const actions = {
  fetchLists({ state, commit, dispatch }, entity) {

    const { timeRange, ...filters } = getFilters(state.storeData);
    if (timeRange) {
      const [startTime, endTime] = timeRange;
      if (startTime) filters.startTime = startTime;
      if (endTime) filters.endTime = formatDate(endTime, 'yyyy-MM-dd') + ' 23:59:59';
    }
    return queryPage({
      data: {
        pageNum: state.pagination.pageNum,
        pageSize: state.pagination.pageSize,
        ...filters,
        ...entity,
      },
    }).then(res => {
      const {
        data: { list, ...pagination },
        moneyData,
      } = res.data;
      dispatch('updatePagination', pagination);
      commit(GET_ROLE_LIST, list);
      commit(MONEY, moneyData);
    });
  },
  storeQueryData({ state, commit, dispatch }, entity) {
    commit(STORE_QUERY_DATA, entity);
  },
};

const mutations = {
  [GET_ROLE_LIST]: (state, list) => {
    state.list = list;
  },
  [STORE_QUERY_DATA](state, list) {
    state.storeData = {
      ...state.storeData,
      ...list,
    };
  },

  [MONEY]: (state, money) => {
    state.money = money;
  },
};

export default {
  namespaced: true,
  modules: {
    pagination,
  },
  state,
  getters,
  actions,
  mutations,
};
