import { fetchOrderMergeRuleList } from '../../../api/orderMerge/orderMerge';

import storeModule from '@/lib/storeModule';
const pagination = storeModule.pagination;
const initFiltersStore = storeModule.filter;
import utils from '@/lib/utils';
const getFilters = utils.getFilters;

const GET_MERGE_RULE_LIST = 'GET_MERGE_RULE_LIST';
const GET_ALL_SELF = 'GET_ALL_SELF';

const initFilters = () => ({
  campusId: undefined,
  deviceType: undefined,
  timeRange: [],
});
const filtersStore = initFiltersStore(initFilters);

const state = () => ({
  list: [],
});

const getters = {
  listData: state => state.list,
};

const actions = {
  fetchOrderMergeRuleList({ commit, dispatch, state, getters }, entity) {
    let { timeRange, ...filters } = getFilters(getters.filters);
    if (timeRange && timeRange.length) {
      const [updateTimeStart, updateTimeEnd] = timeRange;
      if (updateTimeStart) filters.updateTimeStart = updateTimeStart;
      if (updateTimeEnd) filters.updateTimeEnd = updateTimeEnd;
    }
    return fetchOrderMergeRuleList({
      data: {
        pageNum: state.pagination.pageNum,
        pageSize: state.pagination.pageSize,
        ...filters,
        ...entity,
      },
    }).then(res => {
      const { list, ...pagination } = res.data;
      dispatch('updatePagination', pagination);
      commit(GET_MERGE_RULE_LIST, list);
    });
  },
};

const mutations = {
  [GET_MERGE_RULE_LIST](state, list) {
    state.list = list;
  },
};

export default {
  namespaced: true,
  modules: {
    pagination,
    filtersStore,
  },
  state,
  getters,
  actions,
  mutations,
};
