import utils from '@/lib/utils';
const getFilters = utils.getFilters;
import storeModule from '@/lib/storeModule';
const pagination = storeModule.pagination;
const initFiltersStore = storeModule.filter;
import { fetchAreaConfig } from '@/api/appVersion/areaConfig';

const GET_AREA_CONFIG_LIST = 'GET_AREA_CONFIG_LIST';

const initFilters = () => ({
  areaId: undefined,
  isEnabled: null,
  timeRange: [],
});
const filtersStore = initFiltersStore(initFilters);

const state = () => ({
  list: [],
});

const getters = {
  areaConfigList: state => state.list,
};

const actions = {
  fetchAreaConfig({ commit, dispatch, getters }, entity) {
    const { timeRange, ...filters } = getFilters(getters.filters);
    if (timeRange) {
      const [startTime, endTime] = timeRange;
      if (startTime) filters.updatedStartAt = startTime;
      if (endTime) filters.updatedEndAt = endTime;
    }
    fetchAreaConfig({
      params: {
        ...getters.pagination,
        ...filters,
        ...entity,
      },
    })
      .then(res => {
        const { list, ...pagination } = res.data;
        dispatch('updatePagination', pagination);
        commit(GET_AREA_CONFIG_LIST, list);
      })
      .catch(err => {
        console.error(err);
      });
  },
};

const mutations = {
  [GET_AREA_CONFIG_LIST](state, list) {
    state.list = list;
  },
};

export default {
  namespaced: true,
  modules: {
    pagination,
    filtersStore,
  },
  state,
  getters,
  actions,
  mutations,
};
