import storeModule from '@/lib/storeModule';
const pagination = storeModule.pagination;
import { fetchCreditMarginList } from '@/api/cbm/CreditMargin';
import utils from '@/lib/utils';
const getFilters = utils.getFilters;
const formatDate = utils.formatDate;

const GET_CREDIT_LIST = 'GET_CREDIT_LIST';
const STORE_QUERY_DATA='STORE_QUERY_DATA';

const state = () => ({
  list: [],
  creditData:{
    operateId:null,
    areaId:null,
    mode:'',
    timeRange:[],
    updater:'',



  }
});

const getters = {
  listData: state => state.list,
  creditData: state => state.creditData,
};

const actions = {
  fetchCreditMarginList({ state, commit, dispatch }, entity) {
    // const { filters } = getFilters(state.creditData);
    const { timeRange, ...filters } = getFilters(state.creditData);
    if (timeRange) {
      const [beginAt, endAt] = timeRange;
      filters.beginAt = beginAt;
      if (endAt) filters.endAt = formatDate(endAt, 'yyyy-MM-dd') + ' 23:59:59';
    }
    return fetchCreditMarginList({
      params: {
        pageNum: state.pagination.pageNum,
        pageSize: state.pagination.pageSize,
        ...filters,
        ...entity,
      },
    }).then(res => {
      const { list, ...pagination } = res.data;
      dispatch('updatePagination', pagination);
      commit(GET_CREDIT_LIST, list);
    });
  },
  storeQueryData({ commit }, entity) {
    commit(STORE_QUERY_DATA, entity);
  },
};

const mutations = {
  [GET_CREDIT_LIST]: (state, list) => {
    state.list = list;
  },
  [STORE_QUERY_DATA](state, list) {
    state.creditData = {
      ...state.creditData,
      ...list,
    };
  },
};

export default {
  namespaced: true,
  modules: {
    pagination,
  },
  state,
  getters,
  actions,
  mutations,
};
