import storeModule from '@/lib/storeModule';
const pagination = storeModule.pagination;
import utils from '@/lib/utils';
const getFilters = utils.getFilters;
const formatDate = utils.formatDate;
import { fetchEquipmentList } from '@/api/cmb/EuipmentConf';

const GET_EQUIPMENT_LIST = 'GET_EQUIPMENT_LIST';
const STORE_QUERY_DATA='STORE_QUERY_DATA';

const state = () => ({
  list: [],
  equipmentLoginData:{
    operateId:null,
    areaId:null,
    serviceId:null,
    timeRange:[],
    updater:'',
    isClose:'',


  }
});

const getters = {
  listData: state => state.list,
  equipmentLoginData: state => state.equipmentLoginData,
};

const actions = {
  fetchEquipmentList({ state, commit, dispatch }, entity) {

    const { timeRange, ...filters } = getFilters(state.equipmentLoginData);
    if (timeRange) {
      const [beginAt, endAt] = timeRange;
      if (beginAt) filters.beginAt = formatDate(beginAt,'yyyy-MM-dd 00:00:00') ;
      if (endAt) filters.endAt = formatDate(endAt,'yyyy-MM-dd 23:59:59') ;
    }
    return fetchEquipmentList({
      params: {
        pageNum: state.pagination.pageNum,
        pageSize: state.pagination.pageSize,
        ...filters,
        ...entity,
      },
    }).then(res => {
      const { list, ...pagination } = res.data;
      dispatch('updatePagination', pagination);
      commit(GET_EQUIPMENT_LIST, list);
    });
  },
  storeQueryData({ commit }, entity) {
    commit(STORE_QUERY_DATA, entity);
  },
};

const mutations = {
  [GET_EQUIPMENT_LIST]: (state, list) => {
    state.list = list;
  },
  [STORE_QUERY_DATA](state, list) {
    state.equipmentLoginData = {
      ...state.equipmentLoginData,
      ...list,
    };
  },
};

export default {
  namespaced: true,
  modules: {
    pagination,
  },
  state,
  getters,
  actions,
  mutations,
};
