import storeModule from '@/lib/storeModule';
const pagination = storeModule.pagination;
import { fetchActivityList } from '@/api/cmb/activity';
const initFiltersStore = storeModule.filter;
import utils from '@/lib/utils';
const getFilters = utils.getFilters;
const formatDate = utils.formatDate;

const GET_ACTIVITY_LIST = 'GET_ACTIVITY_LIST';
const initFilters = () => ({
  activeName: null,
  serviceId: null,
  timeRange: [],
  state: '',
  activeClass: '',
  payType: '',
});
const filtersStore = initFiltersStore(initFilters);

const state = () => ({
  list: [],
});

const getters = {
  listData: state => state.list,
};

const actions = {
  fetchActivityList({ state, commit, dispatch, getters }, entity) {
    // let filters = getFilters(getters.filters);
    const { timeRange, ...filters } = getFilters(getters.filters);
    console.log(timeRange);
    if (timeRange) {
      const [beginDate, endDate] = timeRange;
      if (beginDate) filters.beginDate = beginDate;
      if (endDate)
        filters.endDate = formatDate(endDate, 'yyyy-MM-dd') + ' 23:59:59';
    }
    return fetchActivityList({
      params: {
        pageNum: state.pagination.pageNum,
        pageSize: state.pagination.pageSize,
        ...filters,
        ...entity,
      },
    }).then(res => {
      const { list, ...pagination } = res.data;
      dispatch('updatePagination', pagination);
      commit(GET_ACTIVITY_LIST, list);
    });
  },
};

const mutations = {
  [GET_ACTIVITY_LIST]: (state, list) => {
    state.list = list;
  },
};

export default {
  namespaced: true,
  modules: {
    pagination,
    filtersStore,
  },
  state,
  getters,
  actions,
  mutations,
};
