import { CancelToken } from 'axios';
import {
  getFeedback,
  getFeedbackById,
  saveFeedback,
} from '@/api/feedBack/feedBack';
import secordStore from './components/feedBackRecord';
import storeModule from '@/lib/storeModule';
const pagination = storeModule.pagination;
import utils from '@/lib/utils';
const getFilters = utils.getFilters;
const formatDate = utils.formatDate;

const FEEDBACK_LIST = 'FEEDBACK_LIST';
const FEEDBACKHANDLEVO = 'FEEDBACKHANDLEVO';
const FEEDBACKHANDLEVOBYID = 'FEEDBACKHANDLEVOBYID';
const LISTBYID = 'LISTBYID';
const STORE_QUERY_DATA = 'STORE_QUERY_DATA';

let cancel = null;

const state = () => ({
  list: [],
  feedbackHandleVo: {
    inProcessing: 0,
    nntreated: 0,
    processed: 0,
  },
  listById: [],
  feedbackHandleVoById: {},
  filterData: {
    //区域
    areaId: null,
    //状态
    state: null,
    //电话
    customerPhone: '',
    //姓名
    customerName: '',
    //开始时间
    startTime: null,
    //结束时间
    endTime: null,
    timeSelect: [],
    whetherGo: false,
  },
});

const getters = {
  list: state => state.list,
  feedbackHandleVo: state => state.feedbackHandleVo,
  listById: state => state.listById,
  feedbackHandleVoById: state => state.feedbackHandleVoById,
  filterData: state => state.filterData,
};

const actions = {
  getFeedback({ commit, state, dispatch }, entity) {
    if (cancel) {
      cancel();
    }
    const { timeSelect, ...filters } = getFilters(state.filterData);

    if (timeSelect && timeSelect.length > 0) {
      filters.startTime = timeSelect[0] ? timeSelect[0] : null;
      filters.endTime = timeSelect[1] ?  formatDate(timeSelect[1] , 'yyyy-MM-dd') + ' 23:59:59' : null;
    }
    return getFeedback({
      data: {
        pageNum: state.pagination.pageNum,
        pageSize: state.pagination.pageSize,
        ...filters,
        ...entity,
      },
      cancelToken: new CancelToken(c => (cancel = c)),
    })
      .then(response => {
        const {
          page: { list, ...pagination },
          feedbackHandleVo,
        } = response.data;
        dispatch('updatePagination', pagination);
        commit(FEEDBACK_LIST, list);
        commit(FEEDBACKHANDLEVO, feedbackHandleVo);
        cancel = null;
      })
      .catch(err => {
        cancel = null;
        console.error(err);
      });
  },

  getFeedbackById({ commit, state, dispatch }, entity) {
    return getFeedbackById({
      params: {
        ...entity,
      },
    }).then(response => {
      console.log(response);
      const { list, feedbackHandleVo } = response.data;
      commit(LISTBYID, list);
      commit(FEEDBACKHANDLEVOBYID, feedbackHandleVo);
    });
  },

  //保存
  saveFeedback({ commit, state, dispatch }, entity) {
    return saveFeedback({
      data: {
        ...entity,
      },
    });
  },
  storeQueryData({ commit }, entity) {
    commit(STORE_QUERY_DATA, entity);
  },
};

const mutations = {
  [FEEDBACK_LIST](state, list) {
    state.list = list;
  },

  [FEEDBACKHANDLEVO](state, feedbackHandleVo) {
    state.feedbackHandleVo = feedbackHandleVo;
  },

  [LISTBYID](state, listById) {
    state.listById = listById;
  },

  [FEEDBACKHANDLEVOBYID](state, feedbackHandleVoById) {
    state.feedbackHandleVoById = feedbackHandleVoById;
  },
  [STORE_QUERY_DATA](state, list) {
    state.filterData = {
      ...state.filterData,
      ...list,
    };
  },
};

export default {
  namespaced: true,
  modules: {
    pagination,
    record: secordStore,
  },
  state,
  getters,
  actions,
  mutations,
};
