import storeModule from '@/lib/storeModule';
const pagination = storeModule.pagination;
import { query4IndiAreaPage } from '@/api/report/consumeOrderAll';

const GET_ORDER_LIST = 'GET_ORDER_LIST';
const CONSUMER_ORDER_ALL = 'CONSUMER_ORDER_ALL';
const STORE_QUERY_DATA = 'STORE_QUERY_DATA';
import utils from '@/lib/utils';
const formatterMoneyToDouble = utils.formatterMoneyToDouble;

const state = () => ({
  list: [],
  consumeOrderAll: {
    unPay: 0,
    pay: 0,
    payAbleMoney: formatterMoneyToDouble(),
    actualMoney: formatterMoneyToDouble(),
    deductionMoney: formatterMoneyToDouble(),
    deductionBean: formatterMoneyToDouble(),
    thirdDiscountMoney: formatterMoneyToDouble(),
  },
  filterData: {
    areaId: null,
    payDateStart: null,
    payDateEnd: null,
    consumeDateStart: null,
    consumeDateEnd: null,
  },
});

const getters = {
  listData: state => state.list,
  consumeOrderAll: state => state.consumeOrderAll,
  filterData: state => state.filterData,
};

const actions = {
  query4IndiAreaPage({ state, commit, dispatch }, entity) {
    return query4IndiAreaPage({
      data: {
        pageNum: state.pagination.pageNum,
        pageSize: state.pagination.pageSize,
        ...entity,
      },
    }).then(res => {
      const {
        data: { list, ...pagination },
        consumerOrderAllCountVo,
      } = res.data;
      dispatch('updatePagination', pagination);
      commit(GET_ORDER_LIST, list);
      commit(CONSUMER_ORDER_ALL, consumerOrderAllCountVo);
    });
  },
  storeQueryData({ commit }, entity) {
    commit(STORE_QUERY_DATA, entity);
  },
};

const mutations = {
  [GET_ORDER_LIST]: (state, list) => {
    state.list = list;
  },
  [CONSUMER_ORDER_ALL]: (state, consumeOrderAll) => {
    let newConsumeOrderAll = {
      unPay: 0,
      pay: 0,
      payAbleMoney: formatterMoneyToDouble(0),
      actualMoney: formatterMoneyToDouble(0),
      deductionMoney: formatterMoneyToDouble(0),
      deductionBean: formatterMoneyToDouble(0),
      thirdDiscountMoney: formatterMoneyToDouble(0),
    };
    if (consumeOrderAll) {
      newConsumeOrderAll = {
        unPay: !consumeOrderAll.unPay ? 0 : consumeOrderAll.unPay,
        pay: !consumeOrderAll.pay ? 0 : consumeOrderAll.pay,
        payAbleMoney: formatterMoneyToDouble(consumeOrderAll.payAbleMoney),
        actualMoney: formatterMoneyToDouble(consumeOrderAll.actualMoney),
        deductionMoney: formatterMoneyToDouble(consumeOrderAll.deductionMoney),
        deductionBean: formatterMoneyToDouble(consumeOrderAll.deductionBean),
        thirdDiscountMoney: formatterMoneyToDouble(
          consumeOrderAll.thirdDiscountMoney
        ),
      };
    }
    state.consumeOrderAll = newConsumeOrderAll;
  },
  [STORE_QUERY_DATA](state, list) {
    state.filterData = {
      ...state.filterData,
      ...list,
    };
  },
};

export default {
  namespaced: true,
  modules: {
    pagination,
  },
  state,
  getters,
  actions,
  mutations,
};
