import storeModule from '@/lib/storeModule';
const pagination = storeModule.pagination;
import { query4IndiMembPage } from '@/api/report/consumeOrderAll';
import { fetchPaymentList } from '@/api/report/index';
const GET_ORDER_LIST = 'GET_ORDER_LIST';
const CONSUMER_ORDER_ALL = 'CONSUMER_ORDER_ALL';
const STORE_QUERY_DATA = 'STORE_QUERY_DATA';
const GET_ALL_PAYMENTS = 'GET_ALL_PAYMENTS';
import utils from '@/lib/utils';
const formatterMoneyToDouble = utils.formatterMoneyToDouble;

const state = () => ({
  list: [],
  listPayments:[],
  consumeOrderAll: {
    unPay: 0,
    pay: 0,
    payAbleMoney: formatterMoneyToDouble(),
    actualMoney: formatterMoneyToDouble(),
    deductionMoney: formatterMoneyToDouble(),
    deductionBean: formatterMoneyToDouble(),
    thirdDiscountMoney: formatterMoneyToDouble(),
  },
  filterData: {
    payDateStart: null,
    payDateEnd: null,
    consumeDateStart: null,
    consumeDateEnd: null,
  },
});

const getters = {
  listPayments: state => state.listPayments,
  listData: state => state.list,
  consumeOrderAll: state => state.consumeOrderAll,
  filterData: state => state.filterData,
};

const actions = {
  query4IndiMembPage({ state, commit, dispatch }, entity) {
    return query4IndiMembPage({
      data: {
        pageNum: state.pagination.pageNum,
        pageSize: state.pagination.pageSize,
        ...entity,
      },
    }).then(res => {
      const {
        data: { list, ...pagination },
        consumerOrderAllCountVo,
      } = res.data;
      dispatch('updatePagination', pagination);
      commit(GET_ORDER_LIST, list);
      commit(CONSUMER_ORDER_ALL, consumerOrderAllCountVo);
    });
  },
  fetchPaymentList({
    state,
    commit,
    dispatch
  }, entity) {
    return fetchPaymentList({
      params: {
        ...entity,
      },
    }).then(res => {
      const list = res.data;
      commit(GET_ALL_PAYMENTS, list);
    });
  },
  storeQueryData({ commit }, entity) {
    commit(STORE_QUERY_DATA, entity);
  },
};

const mutations = {
  [GET_ORDER_LIST]: (state, list) => {
    state.list = list;
  },
  [CONSUMER_ORDER_ALL]: (state, consumeOrderAll) => {
    let newConsumeOrderAll = {
      unPay: !consumeOrderAll.unPay ? 0 : consumeOrderAll.unPay,
      pay: !consumeOrderAll.pay ? 0 : consumeOrderAll.pay,
      payAbleMoney: formatterMoneyToDouble(consumeOrderAll.payAbleMoney),
      actualMoney: formatterMoneyToDouble(consumeOrderAll.actualMoney),
      deductionMoney: formatterMoneyToDouble(consumeOrderAll.deductionMoney),
      deductionBean: formatterMoneyToDouble(consumeOrderAll.deductionBean),
      thirdDiscountMoney: formatterMoneyToDouble(
        consumeOrderAll.thirdDiscountMoney
      ),
    };
    state.consumeOrderAll = newConsumeOrderAll;
  },
  [GET_ALL_PAYMENTS]: (state, list) => {
    state.listPayments = list;
  },
  [STORE_QUERY_DATA](state, list) {
    state.filterData = {
      ...state.filterData,
      ...list,
    };
  },
};

export default {
  namespaced: true,
  modules: {
    pagination,
  },
  state,
  getters,
  actions,
  mutations,
};
