import {
  getPageOrderMoney
} from '@/api/operateOrder';

import utils from '@/lib/utils';
const getFilters = utils.getFilters;
import storeModule from '@/lib/storeModule';
const pagination = storeModule.pagination;
const formatDate = utils.formatDate;

const GET_OPERATE_ORDERS = 'GET_OPERATE_ORDERS';
const STORE_QUERY_DATA = 'STORE_QUERY_DATA';
// let newDate = new Date();
const state = () => ({
  list: [],
  moneyData: {
    consumeMoney: null,
    payMoney: null,
    platformMoney: null,
    prepayMoney: null,
    refundMoney: null,
  },
  storeData: {
    timeRange: [formatDate(new Date(), 'yyyy-MM-dd') + ' 00:00:00',
      formatDate(new Date(), 'yyyy-MM-dd') + ' 23:59:59',
    ],
    orderNumber: null,
    //区域
    customerId: null,
    operateId: null,
    serviceId: null,
    equipmentNum: null,
    equipmentPos: null,
    payType: null,
    whetherGo: false,
  },
});

const getters = {
  list: state => state.list,
  moneyData: state => state.moneyData,
  storeData: state => state.storeData,
};

const actions = {
  getPageOrderMoney({
    commit,
    state,
    dispatch
  }, entity) {
    const {
      timeRange,
      ...filters
    } = getFilters(state.storeData);
    if (timeRange) {
      const [startTime, endTime] = timeRange;
      if (startTime) filters.startTime = startTime;
      if (endTime) filters.endTime = formatDate(endTime, 'yyyy-MM-dd') + ' 23:59:59';
    }
    return getPageOrderMoney({
      data: {
        ...state.pagination,
        ...filters,
        ...entity,
      },
    }).then(response => {
      const {
        list,
        ...pagination
      } = response.data;
      const moneyData = response.moneyData;
      dispatch('updatePagination', pagination);
      commit(GET_OPERATE_ORDERS, {
        list,
        moneyData
      });

    });
  },
  storeQueryData({
    state,
    commit,
    dispatch
  }, entity) {
    commit(STORE_QUERY_DATA, entity);
  },
};

const mutations = {
  [GET_OPERATE_ORDERS](state, {
    list,
    moneyData
  }) {
    state.list = list;
    state.moneyData = moneyData;
  },
  [STORE_QUERY_DATA](state, list) {
    state.storeData = {
      ...state.storeData,
      ...list,
    };
  },
};

export default {
  namespaced: true,
  modules: {
    pagination,
  },
  state,
  getters,
  actions,
  mutations,
};
