import storeModule from '@/lib/storeModule';
const pagination = storeModule.pagination;
const initFiltersStore = storeModule.filter;
import utils from '@/lib/utils';
const getFilters = utils.getFilters;
import {
    pageAppOpenAdvertInfos,
    addAppOpenAdvertInfo,
    updateAppOpenAdvertInfo,
    updateState,
    getEditInfo,
    addAdvertiseRelations,
    listSectionRelations,
    getOperateRecords,
} from '@/api/openAdvert/openAdvert';

const PAGE_DATA = 'PAGE_DATA';
const initFilters = () => ({
    areaId: null,
    advertTitle: null,
    publisherType: null,
    platformSource: null,
    state: null,
    operator: null,
    timeRange: [],
});
const filtersStore = initFiltersStore(initFilters);

const state = () => ({
    list: [],
});

const getters = {
    listData: state => state.list,

};

const actions = {
    pageAppOpenAdvertInfos({
        commit,
        state,
        dispatch,
        getters
    }, entity) {
        let {
            timeRange,
            ...filters
        } = getFilters(getters.filters);
        if (timeRange) {
            const [beginTime, endTime] = timeRange;
            if (beginTime) filters.beginTime = beginTime;
            if (endTime) filters.endTime = endTime;
        }
        return pageAppOpenAdvertInfos({
            data: {
                ...filters,
                ...state.pagination,
                ...entity,
            },
        })
            .then(res => {
                const {
                    list,
                    ...pagination
                } = res.data;
                dispatch('updatePagination', pagination);
                commit(PAGE_DATA, list);
            })
            .catch(err => {
                console.error(err);
            });
    },
    addAppOpenAdvertInfo({
        commit,
        state,
        dispatch
    }, entity) {

        return addAppOpenAdvertInfo({
            data: {
                ...entity,
            }
        })
    },
    getEditInfo({
        commit,
        state,
        dispatch
    }, entity) {
        return getEditInfo({
            params: {
                ...entity
            },
        })
    },
    updateAppOpenAdvertInfo({
        commit,
        state,
        dispatch
    }, entity) {

        return updateAppOpenAdvertInfo({
            data: {
                ...entity,
            }
        })
    },
    updateState({
        commit,
        state,
        dispatch
    }, entity) {

        return updateState({
            params: {
                ...entity,
            }
        })
    },
    addAdvertiseRelations({
        commit,
        state,
        dispatch
    }, entity) {
        // console.log(entity);
        return addAdvertiseRelations({
            data: {
                ...entity,
            }
        })
    },
    listSectionRelations({
        commit,
        state,
        dispatch
    }, entity) {
        return listSectionRelations({
            params: {
                ...entity
            },
        })
    },
    getOperateRecords({
        commit,
        state,
        dispatch
    }, entity) {
        return getOperateRecords({
            params: {
                ...entity
            },
        })
    },
};

const mutations = {
    [PAGE_DATA](state, list) {
        state.list = list;
    },
};

export default {
    namespaced: true,
    modules: {
        filtersStore,
        pagination,
    },
    state,
    getters,
    actions,
    mutations,
};
