import storeModule from '@/lib/storeModule';
const pagination = storeModule.pagination;
import { fetchOrderList } from '@/api/purchasing/order';
const initFiltersStore = storeModule.filter;
import utils from '@/lib/utils';
const getFilters = utils.getFilters;
const formatDate = utils.formatDate;

const GET_ORDER_LIST = 'GET_ORDER_LIST';

const initFilters = () => ({
    operateId: null,
    serviceId: null,
    chargingTime: [],
    contractNumber:'',
    batchNumber:null,
    purchasingTime:[],
    leader:'',
    contactPhone:'',
    paymentTime:[],



});
const filtersStore = initFiltersStore(initFilters);

const state = () => ({
  list: [],
});

const getters = {
  listData: state => state.list,
};

const actions = {
    fetchOrderList({ state, commit, dispatch,getters }, entity) {
    const{paymentTime,purchasingTime,chargingTime,...filters} = getFilters(getters.filters);
    if (paymentTime) {
      const [paymentStartTime, paymentEndTime] = paymentTime;
      if (paymentStartTime) filters.paymentStartTime = paymentStartTime;
      if (paymentEndTime) filters.paymentEndTime = formatDate(paymentEndTime, 'yyyy-MM-dd 23:59:59') ;
    }
    if (purchasingTime) {
      const [purchasingStartTime, purchasingEndTime] = purchasingTime;
      if (purchasingStartTime) filters.purchasingStartTime = purchasingStartTime;
      if (purchasingEndTime) filters.purchasingEndTime =  formatDate(purchasingEndTime, 'yyyy-MM-dd 23:59:59') ;
    }
    if (chargingTime) {
      const [fromTime, endTime] = chargingTime;
      if (fromTime) filters.fromTime = fromTime;
      if (endTime) filters.endTime =  formatDate(endTime, 'yyyy-MM-dd 23:59:59') ;
    }
    return fetchOrderList({
      data: {
        pageNum: state.pagination.pageNum,
        pageSize: state.pagination.pageSize,
        ...filters,
        ...entity,
      },
    }).then(res => {
      const { list, ...pagination } = res.data;
      dispatch('updatePagination', pagination);
      commit(GET_ORDER_LIST, list);
    });
  },
};

const mutations = {
  [GET_ORDER_LIST]: (state, list) => {
    state.list = list;
  },
};

export default {
  namespaced: true,
  modules: {
    pagination,
    filtersStore,
  },
  state,
  getters,
  actions,
  mutations,
};
