import { getAllArea } from '@/api/systemUser/systemUser';

const GET_AREA_LIST = 'GET_AREA_LIST';
const FETCH_STATE = 'FETCH_STATE';
const FETCH_END = 'FETCH_END';
const RESET_LIST = 'RESET_LIST';

const state = () => ({
  fetching: false,
  list: [],
});

const getters = {
  areaList: state => state.list,
};

const actions = {
  getAllArea({ commit, state }, entity) {
    if (state.fetching) return;
    commit(FETCH_STATE);
    return getAllArea({
      params: entity,
    })
      .then(res => {
        const list = res.data;
        commit(GET_AREA_LIST, list);
        commit(FETCH_END);
      })
      .catch(err => {
        console.error(err);
        commit(FETCH_END);
      });
  },
  resetList({ commit }) {
    commit(RESET_LIST);
  },
};

const mutations = {
  [GET_AREA_LIST](state, list) {
    state.list = list;
  },
  [FETCH_STATE](state) {
    state.fetching = true;
  },
  [FETCH_END](state) {
    state.fetching = false;
  },
  [RESET_LIST](state) {
    state.list = [];
  },
};

export default {
  namespaced: true,
  state,
  getters,
  actions,
  mutations,
};
