import { mapGetters, mapActions } from 'vuex';
import store from './store';

export default {
  props: {
    operateId: {
      type: Number,
    },
    adminId: {
      type: Number,
    },
  },
  created() {
    store.install(this.$store);
  },
  mounted() {
    if (
      this.areaList &&
      !this.areaList.length &&
      this.operateId &&
      this.adminId
    ) {
      this.fetchAllAreaList({
        operateId: this.operateId,
        adminId: this.adminId,
      });
    }
  },
  watch: {
    operateId(val) {
      if (val) {
        this.fetchAllAreaList({
          operateId: val,
          adminId: this.adminId,
        });
      } else {
        this.resetAllAreaList();
      }
    },
  },
  data() {
    return {
      areaListDone: false,
    };
  },
  computed: {
    ...mapGetters('operatorArea', ['areaList']),
  },
  methods: {
    ...mapActions('operatorArea', ['getAllArea', 'resetList']),
    fetchAllAreaList(entity) {
      this.getAllArea(entity).then(() => {
        this.areaListDone = true;
      });
    },
    resetAllAreaList() {
      this.areaListDone = false;
      this.resetList();
    },
    getAreaName(id) {
      let item = this.areaList.find(area => area.id === id);
      if (item) {
        return item.areaName;
      } else {
        return '';
      }
    },
  },
};
