import { fetchAllOpenRole } from '@/api/role/role';

const GET_ROLE_LIST = 'GET_ROLE_LIST';
const FETCH_STATE = 'FETCH_STATE';
const FETCH_END = 'FETCH_END';

const state = () => ({
  fetching: false,
  list: [],
});

const getters = {
  roleList: state => state.list,
};

const actions = {
  fetchAllOpenRole({ commit, state }) {
    if (state.fetching) return;
    commit(FETCH_STATE);
    return fetchAllOpenRole()
      .then(res => {
        const list = res.data;
        commit(GET_ROLE_LIST, list);
        commit(FETCH_END);
      })
      .catch(err => {
        console.error(err);
        commit(FETCH_END);
      });
  },
};

const mutations = {
  [GET_ROLE_LIST](state, list) {
    state.list = list;
  },
  [FETCH_STATE](state) {
    state.fetching = true;
  },
  [FETCH_END](state) {
    state.fetching = false;
  },
};

export default {
  namespaced: true,
  state,
  getters,
  actions,
  mutations,
};
